.. djoser documentation master file, created by
   sphinx-quickstart on Fri Jun  2 10:56:45 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to djoser's documentation!
==================================

.. note::

   djoser 2.x is not backward compatible with djoser 1.x

.. toctree::
    :maxdepth: 2
    :caption: Basics

    introduction
    getting_started
    sample_usage
    authentication_backends

.. toctree::
    :maxdepth: 2
    :caption: Settings & API

    settings
    base_endpoints
    token_endpoints
    jwt_endpoints
    social_endpoints
    signals

.. toctree::
    :maxdepth: 1
    :caption: Usage

    migration_guide

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
